Documentation
*************

.. automodule:: federated_monsters


federated_monsters.global_vars
==============================

.. automodule:: federated_monsters.global_vars
   :members:

federated_monsters.monster
==========================

.. automodule:: federated_monsters.monster
   :members:


federated_monsters.box
======================

.. automodule:: federated_monsters.box
   :members:

Databases
=========

Since there are so many databases out there, the Box class instead uses a wrapper class around the necessary database functions. This makes it easy for other developers to implement their own database classes. The generic class is defined in :class:`federated_monsters.db`.

federated_monsters.db
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: federated_monsters.db
   :members:

federated_monsters.berkeley_db
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: federated_monsters.berkeley_db
   :members: